USCFC General Jurisdiction-Reported | US Court of Federal Claims

Skip to main content
Site map

# USCFC General Jurisdiction-Reported

U.S. Court of Federal Claims Opinions
Updated: 6 hours 35 min ago

General Jurisdiction (Reported) | General Jurisdiction (Unreported) | Vaccine (Reported) | Vaccine (Unreported) | Search for:

### 1:07-cv-00006 • PRINCIPAL LIFE INSURANCE COMPANY AND SUBSIDIARIES v. USA

Filed 05/09/2014
REPORTED OPINION denying Motion for Partial Summary Judgment; granting, in part,[129]Cross-Motion for Partial Summary Judgment. Signed by Judge Francis M. Allegra.

Keywords: Tax refund suit; Cross-motions for partial summary judgment; Loss deduction section 165 of the Code; Actual economic loss; Basis allocation Treas. Reg. § 1.61-6(a); Carved-out income interests; Allocation of basis in Perpetuals transaction violated Treasury Regulation; Investment trusts; Sears Regulations Treas. Reg. § 301.7701-4; Multi-class investment trust not trust for tax purposes; Loss disallowed; Custodial arrangements and investment trusts not trusts for tax purposes; Income from Custodial Share Receipts includible in taxable income.

### 1:05-cv-01043 • DELPIN-APONTE, et al v USA

Filed 05/07/2014
REPORTED OPINION denying as moot Motion to Certify Class; denying [117] Motion for Partial Summary Judgment; granting [126] Motion for Summary Judgment. The Clerk is directed to enter judgment. Signed by Judge Victor J. Wolski.

Keywords: re: Order on Motion to Certify Class, Order on Motion for Summary Judgment, Reported Opinion,United States Postal Service (USPS); Fair Labor Standards Act (FLSA), 29 U.S.C. § 207(a)(1) (overtime compensation); Territorial Cost of Living Adjustment (TCOLA); Regular Rate; RCFC 56; Chevron Deference

### 1:13-cv-00137 • LIEBER v. USA

Filed 05/06/2014
REPORTED OPINION and ORDER granting Motion to Dismiss pursuant to Rule 12(b)(1). The Clerk is directed to enter judgment. Signed by Judge Elaine D. Kaplan.

Keywords: Pro Se Plaintiffs; Motion to Dismiss for Lack of Subject Matter Jurisdiction; RCFC 12(b)(1) re: Opinion and Order on Motion to Dismiss.

### 1:12-cv-00303 • HITKANSUT LLC et al v. USA

Filed 05/02/2014
REPORTED OPINION reflecting no redactions from the sealed opinion issued on April 25, 2014. Signed by Judge Charles F. Lettow.

Keywords: Patent case; eligibility for patent protection under 35 U.S.C. § 101; application of the Larson-Miller variant of the Arrhenius equation; ineligibility of mathematical formulae for patent protection; eligibility of novel means of applying a natural law to obtain more efficient and beneficial results re: Reported Opinion (EB)

### 1:13-cv-00016 • TAYLOR-TILLOTSON v. USA

Filed 05/02/2014
REPORTED OPINION and ORDER GRANTING IN PART Motion to Dismiss - Rule 12(b)(1) and (6); GRANTING [27] Motion for Judgment on the Administrative Record; and DENYING [36] Cross Motion. The Clerk is directed to enter judgment. No costs. Signed by Judge Charles F. Lettow.

Keywords: Former spouse's claim for benefits under the Armed Forces Reserve Component Survivor Benefit Plan; 10 U.S.C. § 1448(a)(2)(B); qualifying reserve service; effect of divorce prior to death of reserve component service member re: Reported Opinion and Order.

### 1:13-cv-00346 • BRICKEY v. USA

Filed 05/02/2014
REPORTED ORDER. The Clerk is directed to enter judgment. Signed by Judge Marian Blank Horn.

Keywords: Pro Se Plaintiff; Motion to Dismiss; Lack of Subject Matter Jurisdiction; 28 U.S.C. § 1495; 28 U.S.C. § 2513; Torts; In Forma Pauperis; 28 U.S.C. § 1915 re: Reported Order.

### 1:14-cv-00354 • SPACE EXPLORATION TECHNOLOGIES CORP. v. USA

Filed 04/30/2014
REPORTED ORDER - (re: Preliminary Injunction - docketed for administrative purposes). Signed by Judge Susan G. Braden. (jt1) Copy to parties.

### 1:12-cv-00066 • GONZALES v. USA

Filed 04/30/2014
REPORTED OPINION granting Cross Motion; denying [26] Motion for Summary Judgment. The Clerk is directed to enter judgment. Signed by Chief Judge Patricia E. Campbell-Smith.

Keywords: re: Order on Cross Motion [Dispositive], Order on Motion for Summary Judgment, Reported Opinion Cross-Motions for Summary Judgment, RCFC 56; Luxury Tax, I.R.C. § 4002; Demonstrator Exemption Under I.R.C. § 4002(b)(1); Gas Guzzler Tax; I.R.C. § 4064; Abatement of Penalties and Interest

### 1:12-cv-00204 • DMS IMAGING, INC. et al v. USA

Filed 04/30/2014
REPORTED OPINION on cross-motions for summary judgment. Signed by Judge Mary Ellen Coster Williams.

### 1:06-cv-00872 • GERALD K. KANDEL et al v. USA

Filed 04/30/2014
REPORTED OPINION on Plaintiffs' MOTION to Amend/Correct [123] Order on Motion to Certify Class, specifically the Official Notice to potential class members. Signed by Chief Judge Patricia E. Campbell-Smith.

Keywords re: Order on Motion to Amend/Correct, Reported Opinion -- Class Action; Motion to Amend/Substitute Class Notice; Notice to Potential Class Members; RCFC 23; Best notice that is practicable under the circumstances; Lump-Sum Payment statute; 5 U.S.C. §§ 5551, 5552; Back Pay Act; 5 U.S.C. § 5596; Prejudgment Interest (mf)Keywords: re: [166] Order on Cross Motion [Dispositive], Reported Opinion -- Partial Summary Judgment; RCFC 56; Class Action; Federal Employees; Accrued and Accumulated Annual Leave; 5 U.S.C. §§ 6303, 6304; Separation; Lump-Sum Payment Statute; 5 U.S.C. §§ 5551, 5552, 5553; Cost-of-Living Adjustment (COLA); Locality Pay Adjustment; Sunday Pay; Post Allowance; Back Pay Act; 5 U.S.C. § 5596; Prejudgment Interest.

### 1:06-cv-00872 • GERALD K. KANDEL et al v. USA

Filed 04/30/2014
REPORTED OPINION denying-in-part and staying-in-part Defendant's Cross Motion for Partial Summary Judgment, and [141] Plaintiffs' Cross Motion for Partial Summary Judgment. Signed by Chief Judge Patricia E. Campbell-Smith.

Keywords re: Order on Motion to Amend/Correct, Reported Opinion -- Class Action; Motion to Amend/Substitute Class Notice; Notice to Potential Class Members; RCFC 23; Best notice that is practicable under the circumstances; Lump-Sum Payment statute; 5 U.S.C. §§ 5551, 5552; Back Pay Act; 5 U.S.C. § 5596; Prejudgment Interest (mf)Keywords: re: [166] Order on Cross Motion [Dispositive], Reported Opinion -- Partial Summary Judgment; RCFC 56; Class Action; Federal Employees; Accrued and Accumulated Annual Leave; 5 U.S.C. §§ 6303, 6304; Separation; Lump-Sum Payment Statute; 5 U.S.C. §§ 5551, 5552, 5553; Cost-of-Living Adjustment (COLA); Locality Pay Adjustment; Sunday Pay; Post Allowance; Back Pay Act; 5 U.S.C. § 5596; Prejudgment Interest.

### 1:08-cv-00533 • CARDIOSOM, L.L.C. v. USA

Filed 04/30/2014
REPORTED ORDER denying Motion to Dismiss - Rule 12(b)(1) and (6). Signed by Chief Judge Patricia E. Campbell-Smith.

Keywords: re: Order on Motion to Dismiss - Rule 12(b)(1) and (6), Reported Order, Chevron Deference; Regulatory Interpretation; Motion to Dismiss for Lack of Subject Matter Jurisdiction under RCFC 12(b)(1); Motion to Dismiss for Failure to State a Claim under RCFC 12(b)(6); Motion for Summary Judgment under RCFC 56.

### 1:13-cv-00413 • VANE MINERALS (US), LLC v. USA

Filed 04/29/2014
REPORTED OPINION granting Motion to Dismiss - Rule 12(b)(1) and (6). The Clerk is directed to enter judgment. Signed by Judge Susan G. Braden.

Keywords: re: Order on Motion to Dismiss - Rule 12(b)(1) and (6), Reported Opinion; Administrative Procedure Act, 5 U.S.C. § 551 et seq.; Arizona Wilderness Act of 1984, Pub. L. 98-406, 98 Stat. 1485 (as amended);Federal Land Policy and Management Act of 1976, 43 U.S.C. § 1701 et seq.; Mining Law of 1872, 30 U.S.C. §§ 22-47; National Environmental Policy Act of 1969, 42 U.S.C. § 4321 et seq.;Surface Mining Control and Reclamation Act of 1977, 30 U.S.C. §§ 1201-1328 (governing surface coal mining operations);Ripeness; 36 C.F.R. § 228.4(c) (plan of operations for mining on Forest Service lands); 36 C.F.R. § 228.5(a)(1)-(5) (approving a plan of operations for mining on Forest Service lands);43 C.F.R. § 3809.100(a) (provisions applicable to segregated or withdrawn lands);43 C.F.R. § 3809.401(b) (requirements for plan of operations on BLM lands);43 C.F.R. § 3832.11(c)(1) (locating mining claims);RCFC 12(b)(1) (jurisdiction); RCFC 12(b)(6) (failure to state a claim).

### 1:99-cv-02051 • ATHEY et al v. USA

Filed 04/28/2014
REPORTED OPINION granting-in-part, denying-in-part, and staying-in-part Plaintiffs' MOTION for Partial Summary Judgment. Signed by Chief Judge Patricia E. Campbell-Smith.

Keywords: re: Opinion and Order on Motion for Partial Summary Judgment, Reported Opinion: Partial Summary Judgment; RCFC 56; Class Action; Veterans Affairs (VA); 38 U.S.C. §§ 7401, 7408; General Schedule Federal Employees; Accrued and Accumulated Annual Leave; 5 U.S.C. §§ 6303, 6304; Separation; Lump-Sum Payment Statute; 5 U.S.C. §§ 5551, 5552, 5553; 5 C.F.R. § 550.1205; Cost-of-Living Adjustment (COLA); Locality Pay Adjustment

### 1:13-cv-00323 • DRIESSEN v. USA

Filed 04/25/2014
REPORTED Order granting Motion to Dismiss - Rule 12(b)(1) and (6). The Clerk is directed to enter judgment. Signed by Judge Marian Blank Horn. Copy to parties.

Keywords: Pro Se Plaintiff; Motion to Dismiss; Lack of Subject Matter Jurisdiction; Failure to State a Claim; Intellectual Property; Copyright: Implied-in-Fact Contract re: Reported Order on Motion to Dismiss.

### 1:14-cv-00155 • HUGHES GROUP, LLC v. USA

Filed 04/22/2014
REPORTED OPINION, originally filed under seal on April 14, 2014. Signed by Judge Nancy B. Firestone.

Keywords: re: Reported Opinion Bid Protest, Motion to Dismiss, Lack of Standing; Failure to Establish Substantial Chance of Award

### 1:08-cv-00610 • TEXTAINER EQUIPMENT MANAGEMENT LIMITED, ET AL. v. USA

Filed 04/22/2014
REPORTED OPINION granting-in-part and denying-in-part Motion for Summary Judgment and granting-in-part and denying-in-part [97] Cross-Motion for Summary Judgment. Proposed Judgment due by 5/9/2014. Signed by Judge Nancy B. Firestone.

Keywords: re: Reported Opinion, Standing To Bring Takings Claim; Assignment of Claims Act; Subrogation; RCFC 17 Substitution; Physical Possession and Use for Public Purpose; Interest on takings claim

### 1:12-cv-00488 • MEYER GROUP LTD v. USA

Filed 04/18/2014
REPORTED OPINION denying Defendant's Motion to Amend Answer to Assert Counterclaims pursuant to Rule 15(a). Signed by Judge Mary Ellen Coster Williams.

### 1:13-cv-01012 • HYPERION, INC. v. USA

Filed 04/17/2014
REPORTED OPINION reflecting redactions from the sealed opinion issued on April 9, 2014. Signed by Judge Charles F. Lettow.

Keywords: Post-award bid protest; small business set aside; lowest price technically acceptable procurement; limitation on subcontracting; FAR § 52.219-14(c); required inclusion in proposals of analyses to establish the reasonableness of proposed subcontract prices; FAR § 15.404-3(b)(1)-(2); prejudice; equitable relief re: Reported Opinion (EB)

### 1:10-cv-00444 • AFFILIATED CONSTRUCTION GROUP, INC., v. USA

Filed 04/16/2014
REPORTED OPINION ( Status Report due by 4/30/2014) granting Motion to Dismiss - Rule 12(b)(6). Signed by Judge Victor J. Wolski.

Keywords: re: Order on Motion to Dismiss - Rule 12(b)(6), Reported Opinion RCFC 12(b)(6) motion for partial dismissal; Contract Disputes Act; firm-fixed-price contract, 48 C.F.R § 16.202-1; no adjustments for cost experience; new claim based on different operative facts.

## Pages

- 1
- 2
- 3
- 4
- 5
- 6
- 7
- 8
- 9
- …
- next ›
- last »